@@ -1269,8 +1269,8 @@ class AurPackage(BasePackage):
             return self._find(key, 'URL')
         elif key == 'aururl':
             try:
-                return '%s?ID=%d' % (AUR_HTM, int(self._base.get('ID')))
-            except (ValueError, TypeError):
+                return os.path.join(AUR_HTM, self._base.get('Name'))
+            except TypeError:
                 pass
         elif key == 'license':
             license = self._find(key, 'License')
